% !TeX encoding = UTF-8
% LaTeX class for Logical Investigations journal
% version: v.1.6 2021/09/18
% author: Konkov Artem
%         konkov@physics.msu.ru

\LoadClass[leqno,11pt]{book}
\NeedsTeXFormat{LaTeX2e}
\RequirePackage{geometry}
\geometry{
	paperwidth=176mm,
	paperheight=240mm,
%	total={131mm,200mm},
%	textwidth=131mm,
%	textheight=200mm,
	top=20mm,
	bottom=20mm,
	left=25mm,
	right=20mm,
	includehead,
	headheight=5mm,
	voffset=0mm,
	nofoot,
	headsep=2mm,
	marginparwidth=0mm,
	marginparsep=0mm,
	layoutoffset={0mm,0mm},
%	showframe
}
\setlength{\footskip}{10mm}

\RequirePackage[utf8]{inputenc}
\RequirePackage[T1,T2A]{fontenc}
\RequirePackage[russian,british]{babel}
\RequirePackage[]{babelbib}
%\RequirePackage{hyphenat}
%\RequirePackage[tpic]{xy}
\RequirePackage{graphicx}
\graphicspath{{articles/}}
\RequirePackage{etoolbox}
\RequirePackage{multido}
\RequirePackage{titlesec}
\RequirePackage[bookmarks=false,unicode,hyperfootnotes=false,hypertexnames=false]{hyperref}
\RequirePackage{url}
\RequirePackage{amsmath}
%\babelprovide[import, main]{polytonicgreek}
%\RequirePackage[GlyphNames]{teubner}
\RequirePackage{amsthm}
%\usepackage[style=authoryear,backend=bibtex]{biblatex}
%\RequirePackage[resetlabels]{multibib}
%\usepackage{filecontents}

\RequirePackage{enumitem}
\RequirePackage[mathscr]{eucal}
\RequirePackage{mathtext}
\RequirePackage{amssymb,latexsym,amsfonts,array,dsfont}
\RequirePackage{units}
\RequirePackage{longtable}
%\usepackage{blindtext}
\RequirePackage{caption}
\DeclareCaptionFormat{LItableRUS}{\small\hfill#1\vspace{2mm}\newline{\bf#3}}
\RequirePackage{setspace}
%\usepackage[dvips,usenames]{color}
%запрет висячих строк
\clubpenalty=9996
\widowpenalty=9999
\brokenpenalty=4991
\predisplaypenalty=10000
\postdisplaypenalty=1549
\displaywidowpenalty=1602
% чтобы не было переполнения строк
\sloppy 
%\usepackage{lscape}
%\usepackage{longtable}
%\usepackage{soul}
%\usepackage{hhline}
\RequirePackage{bussproofs}
\RequirePackage{arydshln}
\RequirePackage{enumitem}



\newcounter{NumberOfAuthors}
\newcounter{NumberOfAuthorsMinusOne}
\setcounter{NumberOfAuthorsMinusOne}{-1}
\newif\ifOnlyENGarticle
\OnlyENGarticletrue
\newcommand\addLIautorLastNameRUS[1]{
	\OnlyENGarticlefalse
	\stepcounter{NumberOfAuthors}
	\stepcounter{NumberOfAuthorsMinusOne}
	\csdef{LastNameRUS\theNumberOfAuthors}{#1}}
\newcommand\addLIautorFirstNameRUS[1]{\csdef{FirstNameRUS\theNumberOfAuthors}{#1}}
\newcommand\addLIautorMiddleNameRUS[1]{\csdef{MiddleNameRUS\theNumberOfAuthors}{#1}}
\newcommand\addLIautorInitialNameRUS[1]{\csdef{InitialNameRUS\theNumberOfAuthors}{#1}}
\newcommand\addLIautorOrgRUS[1]{\csdef{OrgRUS\theNumberOfAuthors}{#1}}
\newcommand\addLIautorOrgAdressRUS[1]{\csdef{OrgAdressRUS\theNumberOfAuthors}{#1}}
\newcommand\addLIautorAdditionalOrgRUS[1]{\csdef{AdditionalOrgRUS\theNumberOfAuthors}{#1. \newline}}
\newcommand\addLIautorAdditionalOrgAdressRUS[1]{\csdef{AdditionalOrgAdressRUS\theNumberOfAuthors}{#1. \newline}}


\newcommand\addLIautorLastNameENG[1]{
\ifOnlyENGarticle
\stepcounter{NumberOfAuthors}
\stepcounter{NumberOfAuthorsMinusOne}
\fi
\csdef{LastNameENG\theNumberOfAuthors}{#1}}
\newcommand\addLIautorFirstNameENG[1]{\csdef{FirstNameENG\theNumberOfAuthors}{#1}}
\newcommand\addLIautorMiddleNameENG[1]{\csdef{MiddleNameENG\theNumberOfAuthors}{#1}}
\newcommand\addLIautorInitialNameENG[1]{\csdef{InitialNameENG\theNumberOfAuthors}{#1}}
\newcommand\addLIautorOrgENG[1]{\csdef{OrgENG\theNumberOfAuthors}{#1}}
\newcommand\addLIautorOrgAdressENG[1]{\csdef{OrgAdressENG\theNumberOfAuthors}{#1}}
\newcommand\addLIautorAdditionalOrgENG[1]{\csdef{AdditionalOrgENG\theNumberOfAuthors}{#1, \newline}}
\newcommand\addLIautorAdditionalOrgAdressENG[1]{\csdef{AdditionalOrgAdressENG\theNumberOfAuthors}{#1. \newline}}
\newcommand\addLIautorEmail[1]{\csdef{Email\theNumberOfAuthors}{#1}}
\newcommand\getLIautor[1]{\csuse{#1}}
\newcommand{\LIarticleNameRUS}[1]{\def\WLIarticleNameRUS{#1}}
\newcommand{\LIarticleTranslitNameRUS}[1]{\def\WLIarticleTranslitNameRUS{#1}}
\newcommand{\LIarticleNameENG}[1]{\def\WLIarticleNameENG{#1}}
\newcommand{\LIautorLastNameRUS}[1]{\addLIautorLastNameRUS{#1}}
\newcommand{\LIautorFirstNameRUS}[1]{\addLIautorFirstNameRUS{#1}}
\newcommand{\LIautorMiddleNameRUS}[1]{\addLIautorMiddleNameRUS{#1}}
\newcommand{\LIautorInitialNameRUS}[1]{\addLIautorInitialNameRUS{#1}}
\newcommand{\LIautorOrgRUS}[1]{\addLIautorOrgRUS{#1}}
\newcommand{\LIautorOrgAdressRUS}[1]{\addLIautorOrgAdressRUS{#1}}
\newcommand{\LIautorAdditionalOrgRUS}[1]{\addLIautorAdditionalOrgRUS{#1}}
\newcommand{\LIautorAdditionalOrgAdressRUS}[1]{\addLIautorAdditionalOrgAdressRUS{#1}}
\newcommand{\LIautorLastNameENG}[1]{\addLIautorLastNameENG{#1}}
\newcommand{\LIautorFirstNameENG}[1]{\addLIautorFirstNameENG{#1}}
\newcommand{\LIautorMiddleNameENG}[1]{\addLIautorMiddleNameENG{#1}}
\newcommand{\LIautorInitialNameENG}[1]{\addLIautorInitialNameENG{#1}}
\newcommand{\LIautorOrgENG}[1]{\addLIautorOrgENG{#1}}
\newcommand{\LIautorOrgAdressENG}[1]{\addLIautorOrgAdressENG{#1}}
\newcommand{\LIautorAdditionalOrgENG}[1]{\addLIautorAdditionalOrgENG{#1}}
\newcommand{\LIautorAdditionalOrgAdressENG}[1]{\addLIautorAdditionalOrgAdressENG{#1}}
\newcommand{\LIautorEmail}[1]{\protect\addLIautorEmail{#1}}




% Строка И.И. Фамилия
\def\WLIautorInitialLastNameRUS{\getLIautor{InitialNameRUS1}~\getLIautor{LastNameRUS1}\ignorespaces}
\def\WLIautorInitialLastNameRUSappend{\Multido{\i=2+1}{\theNumberOfAuthorsMinusOne}{, \getLIautor{InitialNameRUS\i}~\getLIautor{LastNameRUS\i}}}
\appto\WLIautorInitialLastNameRUS{\WLIautorInitialLastNameRUSappend}

\def\WLIautorInitialLastNameENG{\getLIautor{FirstNameENG1}~\getLIautor{MiddleNameENG1}~\getLIautor{LastNameENG1}\ignorespaces}
\def\WLIautorInitialLastNameENGappend{\Multido{\i=2+1}{\theNumberOfAuthorsMinusOne}{, \getLIautor{FirstNameENG\i}~\getLIautor{MiddleNameENG\i}~\getLIautor{LastNameENG\i}}}
\appto\WLIautorInitialLastNameENG{\WLIautorInitialLastNameENGappend}


% Строка Фамилия И.И.
\def\WLIautorLastInitialNameRUS{\getLIautor{LastNameRUS1}~\getLIautor{InitialNameRUS1}\ignorespaces}
\def\WLIautorLastInitialNameRUSappend{\Multido{\i=2+1}{\theNumberOfAuthorsMinusOne}{, \getLIautor{LastNameRUS\i}~\getLIautor{InitialNameRUS\i}}}
\appto\WLIautorLastInitialNameRUS{\WLIautorLastInitialNameRUSappend}

\def\WLIautorLastInitialNameENG{\getLIautor{LastNameENG1}~\getLIautor{InitialNameENG1}\ignorespaces}
\def\WLIautorLastInitialNameENGappend{\Multido{\i=2+1}{\theNumberOfAuthorsMinusOne}{, \getLIautor{LastNameENG\i}~\getLIautor{InitialNameENG\i}}}
\appto\WLIautorLastInitialNameENG{\WLIautorLastInitialNameENGappend}

% Блок Автор инфо
\def\LIaboutAutorBlockRUS{\Multido{\i=1+1}{\theNumberOfAuthors}{
		\begin{list}{}{\leftmargin=0pt}\item[]\footnotesize\noindent
			\noindent\textbf{\getLIautor{FirstNameRUS\i}~\getLIautor{MiddleNameRUS\i}~\getLIautor{LastNameRUS\i}}\newline
			\getLIautor{OrgRUS\i}. \newline
			\getLIautor{OrgAdressRUS\i}.\newline
			\getLIautor{AdditionalOrgRUS\i}
			\getLIautor{AdditionalOrgAdressRUS\i}
			E-mail: \href{mailto:\getLIautor{Email\i}}{\nolinkurl{\getLIautor{Email\i}}}
		\end{list}
	}
}

\def\LIaboutAutorBlockENG{\Multido{\i=1+1}{\theNumberOfAuthors}{
		\begin{list}{}{\leftmargin=0pt}\item[]\footnotesize\noindent
			\noindent\textbf{\getLIautor{FirstNameENG\i} \getLIautor{MiddleNameENG\i} \getLIautor{LastNameENG\i} }\newline
			\getLIautor{OrgENG\i}, \newline
			\getLIautor{OrgAdressENG\i}.\newline
			\getLIautor{AdditionalOrgENG\i}
			\getLIautor{AdditionalOrgAdressENG\i}
			E-mail: \href{mailto:\getLIautor{Email\i}}{\nolinkurl{\getLIautor{Email\i}}}
		\end{list}
	}
}
\def\OnlyENGarticleAction{
	\let\WLIautorInitialLastNameRUS\WLIautorInitialLastNameENG
	\let\WLIautorLastInitialNameRUS\WLIautorLastInitialNameENG
	\let\WLIarticleNameRUS\WLIarticleNameENG
}
%%%%%%%%%%%%%

% !TeX Ccылка на грант %
\def\WLIthanksRUS{}
\newcommand{\LIthanksRUS}[1]{
	\ifx&#1&
	\else
	\def\WLIthanksRUS{\setcounter{footnote}{-1}\renewcommand{\thefootnote}{$*$~}\footnote{#1}}
	\fi
}
\def\WLIthanksENG{}
\newcommand{\LIthanksENG}[1]{
	\ifx&#1&
	\else
	\def\WLIthanksENG{\vspace{2mm}\small\noindent{\bf Acknowledgements.} #1}
	\fi
}
%%%%%%%%%%%%%%
% !TeX УДК %
\def\LIarticleUDK#1{\def\LIarticleUDK{#1}}

% !TeX Главные окружения %
%\def\enddocument{%
%	\let\AtEndDocument\@firstofone
%	%	\@enddocumenthook
%	%	\@checkend{document}%
%	%	\clear@document
%	%	\check@aux
%	%	\deadcycles\z@
%	\@@end
%}%
\newenvironment{LIarticle}{
	\document
	\def\LIarticleLabel{LI}
	\SetPrivateLabeling
	\pagestyle{plain}
}{\let\AtEndDocument\@firstofone\@@end}

\newcommand{\LIarticleRUSenvPrefix}{}


\newenvironment{LIarticleRUS}{
	\selectlanguage{russian}
	\LIarticleRUSenvPrefix
	\def\LIarticleLangInd{RUS}
	\def\LIDefinitionName{Определение}
	\def\LITheoremName{Теорема}
	\def\LIMetatheoremName{Метатеорема}
	\def\LILemmaName{Лемма}
	\def\LIPropositionName{Утверждение}
	\def\LIProofName{Доказательство}
	\def\LICorollaryName{Следствие}
	\def\LIExampleName{Пример}
	\def\LIRemarkName{Замечание}
	\def\LIFactName{Факт}
	\def\LIConventionName{Соглашение}
	\def\LIAbstractName{Аннотация}
	\def\LIKeywordsName{Ключевые слова}
	\def\LIbibliographyName{Литература}
%	\renewcommand{\figurename}{Рис.}
%	\renewcommand{\tablename}{Таблица}
	\captionsetup[figure]{font={small},labelformat={default},labelsep=period}
	\captionsetup[table]{format=LItableRUS,position=top}
	\hspace{0pt}
	\begin{center}
		\vspace{2mm}
		\textsc{\normalsize\WLIautorInitialLastNameRUS}\\
		\vspace{3mm}
		\begin{spacing}{1.3}\textbf{\Large\WLIarticleNameRUS\WLIthanksRUS}\end{spacing}
	\end{center}
	\LIaboutAutorBlockRUS
}{
\clearpage
\setcounter{footnote}{0}
}

\newcommand{\LIarticleENGenvPrefix}{}

\newenvironment{LIarticleENG}{
	\selectlanguage{british}
	\LIarticleENGenvPrefix
	\def\LIarticleLangInd{ENG}
	\def\LIDefinitionName{Definition}
	\def\LITheoremName{Theorem}
	\def\LIMetatheoremName{Metatheorem}
	\def\LILemmaName{Lemma}
	\def\LIPropositionName{Proposition}
	\def\LIProofName{Proof}
	\def\LICorollaryName{Corollary}
	\def\LIExampleName{Example}
	\def\LIRemarkName{Remark}
	\def\LIFactName{Fact}
	\def\LIConventionName{Convention}
	\def\LIAbstractName{Abstract}
	\def\LIKeywordsName{Keywords}
	\def\LIbibliographyName{References}
	\renewcommand{\figurename}{Fig.}
%	\renewcommand{\tablename}{Table}
	\captionsetup[figure]{font={small},labelformat={default},labelsep=period}
	\captionsetup[table]{font={small},labelformat={default},labelsep=period}
	\hspace{0pt}
	\begin{center}
		\vspace{2mm}
		\textsc{\normalsize\WLIautorInitialLastNameENG}\\
		\vspace{3mm}
		\begin{spacing}{1.3}\textbf{\Large\WLIarticleNameENG}\end{spacing}
	\end{center}
	\LIaboutAutorBlockENG
}{
\label{LastPage}
\hspace{0pt}
\clearpage
\setcounter{footnote}{0}
%\renewcommand{\figurename}{Рис.}
%\renewcommand{\tablename}{Таблица}
}

% !TeX Окружение для аннотации %
\newenvironment{LIabstract}{\setlength\parindent{0pt}\begin{list}{}{\leftmargin=0pt}
		\item[]\footnotesize{\bf\LIAbstractName:}}
	{\end{list}}
%%%%%%%%%%%%%%

\def\LICitationRUS{}
\def\LICitationENG{}
% !TeX Окружение для ключевых слов %
\newenvironment{LIkeywords}{\begin{list}{}{\setlength{\leftmargin}{0pt}\setlength{\topsep}{0mm}}
		\item[]\footnotesize\noindent{\bf\LIKeywordsName:}}%
	{\csuse{LICitation\LIarticleLangInd}\end{list}\vspace{3mm}}
%%%%%%%%%%%%%%

% !TeX Библиография %
\makeatletter
\renewcommand\@biblabel[1]{#1 --}
\renewenvironment{thebibliography}[1]{
	\small
%	\newpage \vspace*{.7cm}\begin{center}{\large{\@bibname}}\end{center}\vspace{1cm}\thispagestyle{empty}
	\section*{\bibname}
	\list{\@biblabel{\@arabic\c@enumiv}}%
	{\settowidth\labelwidth{\@biblabel{\hspace{-0.6mm}#1}}%
		\leftmargin\parindent
		\parsep 0pt plus 1pt
		\itemsep 2pt plus 1pt
		\usecounter{enumiv}
		\let\p@enumiv\@empty
		\renewcommand\theenumiv{\@arabic\c@enumiv}}%
	\renewcommand\newblock{\hskip .11em \@plus.33em \@minus.07em}%
	\sloppy\clubpenalty10000\widowpenalty10000%
	\sfcode`\.=\@m}
{\def\@noitemerr
	{\@latex@warning{Empty `thebibliography' environment}}%
	\endlist}
\makeatother


\newenvironment{LIbibliography}{
	\expandafter\ifstrequal\expandafter{\LIarticleLangInd}{ENG}{\WLIthanksENG}{}
	\renewcommand{\bibname}{\LIbibliographyName}
	\begin{thebibliography}{0}
	}
	{\end{thebibliography}}
%%%%%%%%%%%%%%






% !TeX Формат заголовков разделов %
\renewcommand\thesection{\arabic{section}.}
\renewcommand\thesubsection{\thesection\arabic{subsection}.}
\renewcommand\thesubsubsection{\thesubsection\arabic{subsubsection}.}
\titleformat*{\section}{\large\bfseries}
\titleformat*{\subsection}{\normalsize\bfseries}
\titleformat*{\subsubsection}{\normalsize\bfseries}
\titleformat*{\paragraph}{\normalsize\bfseries}
\titleformat*{\subparagraph}{\normalsize\bfseries}

\titlespacing{\section}{0mm}{3mm}{2mm}
\titlespacing{\subsection}{0mm}{2mm}{1mm}
\titlespacing{\subsubsection}{0mm}{0mm}{0mm}
\titlespacing{\paragraph}{0mm}{0mm}{0mm}
\titlespacing{\subparagraph}{0mm}{0mm}{0mm}
%%%%%%%%%%%%%%
\renewcommand\thefigure{\arabic{figure}}
\renewcommand\thetable{\arabic{table}}


% !TeX Окружения для теорем и пр. %
\theoremstyle{plain}
\newtheorem{theorem}{\bf \LITheoremName}
\newtheorem*{theorem*}{\bf \LITheoremName}
\newtheorem{metatheorem}{\bf \LIMetatheoremName}
\newtheorem*{metatheorem*}{\bf \LIMetatheoremName}
\newtheorem{lemma}{\bf \LILemmaName}
\newtheorem*{lemma*}{\bf \LILemmaName}

\theoremstyle{definition}
\newtheorem{definition}{\bf \LIDefinitionName}
\newtheorem*{definition*}{\bf \LIDefinitionName}
\newtheorem{proposition}{\bf \LIPropositionName}
\newtheorem*{proposition*}{\bf \LIPropositionName}
\renewenvironment{proof}{\begin{trivlist}\item[] \textit{\textbf{\LIProofName.}}}
	{\hspace*{\fill}$\blacksquare$\end{trivlist}}
\newenvironment{proof*}{\begin{trivlist}\item[]{\it \LIProofName}}
	{\hspace*{\fill}$\blacksquare$\end{trivlist}}
\newtheorem{corollary}{\bf \LICorollaryName}
\newtheorem*{corollary*}{\bf \LICorollaryName}
\newtheorem{example}{\bf \LIExampleName}
\newtheorem*{example*}{\bf \LIExampleName}
\newtheorem{remark}{\bf \LIRemarkName}
\newtheorem*{remark*}{\bf \LIRemarkName}
\newtheorem{fact}{\bf \LIFactName}
\newtheorem*{fact*}{\bf \LIFactName}
\newtheorem{convention}{\bf \LIConventionName}
\newtheorem*{convention*}{\bf \LIConventionName}

% !TeX Конфликт одноимённых меток, добавление \LIarticleLabel
\RequirePackage{letltxmacro}
\makeatletter
\AtBeginDocument{
	\LetLtxMacro{\globallabel}{\label}%
	\LetLtxMacro{\globalltx@label}{\ltx@label}%
	\LetLtxMacro{\globalref}{\ref}%
	\LetLtxMacro{\globalpageref}{\pageref}%
	\LetLtxMacro{\globalcitex}{\@citex}%
	\LetLtxMacro{\globalbibitem}{\bibitem}%

	\def\LI@label#1{\globallabel{\LIarticleLabel:#1}}
	\def\LI@ref#1{\globalref{\LIarticleLabel:#1}}
	\def\LI@pageref#1{\globalpageref{\LIarticleLabel:#1}}

	\DeclareRobustCommand\LI@bibitem{\@ifnextchar[{\LI@@@bibitem}{\LI@@bibitem}}

	\def\LI@@bibitem#1{\globalbibitem{\LIarticleLabel:\LIarticleLangInd:#1}}
	\def\LI@@@bibitem[#1]#2{\expandafter\globalbibitem[{#1}]{\LIarticleLabel:\LIarticleLangInd:#2}}
	
	\def\LI@citex[#1]#2{%
		\let\@citea\@empty
		\@cite{\@for\@citeb:=#2\do
			{\@citea\def\@citea{;\penalty\@m\ }%
				\edef\@citeb{\LIarticleLabel:\LIarticleLangInd:\expandafter\@firstofone\@citeb\@empty}%
				\if@filesw\immediate\write\@auxout{\string\citation{\@citeb}}\fi
				\@ifundefined{b@\@citeb}{\mbox{\reset@font\bfseries ?}%
					\G@refundefinedtrue
					\@latex@warning{Citation `\@citeb' on page \thepage \space undefined}}%
				{{\csname b@\@citeb\endcsname}}}}{#1}%
	}
}
\newcommand\SetPrivateLabeling{%
	\let\label\LI@label
	\let\ltx@label\LI@label % AmSLaTeX
	\let\ref\LI@ref
	\let\pageref\LI@pageref
	\let\@citex\LI@citex
	\let\bibitem\LI@bibitem
}
\newcommand\RestoreDefaultLabeling{
	\let\label\globallabel
	\let\ltx@label\globalltx@label
	\let\ref\globalref
	\let\pageref\globalpageref
	\let\@citex\globalcitex
	\let\bibitem\globalbibitem
}
\makeatother
%%%%%%%%%%%%%%